Index: pkg/observe/lib/src/microtask.dart |
diff --git a/pkg/observe/lib/src/microtask.dart b/pkg/observe/lib/src/microtask.dart |
index 6689a8ca488c21eeebe969f703dbfebaed24613b..307502afa922b3f6eeb79fb57e83878ee1b0d82b 100644 |
--- a/pkg/observe/lib/src/microtask.dart |
+++ b/pkg/observe/lib/src/microtask.dart |
@@ -6,7 +6,8 @@ |
* *Warning*: this library is **internal**, and APIs are subject to change. |
* |
* Wraps a callback using [wrapMicrotask] and provides the ability to pump all |
* observable objects and [runAsync] calls via [performMicrotaskCheckpoint]. |
*/ |
library observe.src.microtask; |
@@ -21,7 +22,7 @@ import 'package:observe/observe.dart' show Observable; |
* This change pumps events relevant to observers and data-binding tests. |
* This must be used inside an [observeTest]. |
* |
* Executes all pending [runAsync] calls on the event loop, as well as |
* performing [Observable.dirtyCheck], until there are no more pending events. |
* It will always dirty check at least once. |
*/ |
@@ -66,4 +67,4 @@ runMicrotask(body()) => runZonedExperimental(() { |
} finally { |
performMicrotaskCheckpoint(); |
} |
-}, onRunAsync: (callback) => _pending.add(callback)); |
+}, onScheduleMicrotask: (callback) => _pending.add(callback)); |
@@ -6,7 +6,8 @@ |
* |
* Wraps a callback using [wrapMicrotask] and provides the ability to pump all |
- * observable objects and [runAsync] calls via [performMicrotaskCheckpoint]. |
+ * observable objects and [scheduleMicrotask] calls via |
+ * [performMicrotaskCheckpoint]. |
*/ |
library observe.src.microtask; |
@@ -21,7 +22,7 @@ import 'package:observe/observe.dart' show Observable; |
* This must be used inside an [observeTest]. |
* |
- * Executes all pending [runAsync] calls on the event loop, as well as |
+ * Executes all pending [scheduleMicrotask] calls on the event loop, as well as |
* performing [Observable.dirtyCheck], until there are no more pending events. |
* It will always dirty check at least once. |